@@ -8,6 +8,12 @@
   shiny::addResourcePath("sF", system.file("www", package = "shinyFiles"))
 }
 
+#' check for NULL or NA
+#'
+#' @noRd
+#'
+.is_not <- function(x) length(x) == 0 || (length(x) == 1 && is.na(x))
+
 #' Run a simple example app using the shinyFiles functionality
 #'
 #' When the function is invoked a shiny app is started showing a very simple
@@ -73,11 +79,16 @@ getVolumes <- function(exclude) {
     } else if (osSystem == "Windows") {
       wmic <- paste0(Sys.getenv("SystemRoot"), "\\System32\\Wbem\\WMIC.exe")
       if (!file.exists(wmic)) {
-        message("\nThe wmic program does not seem to be in the default location")
-        message("Please report this problem and include output from the command") 
-        message("'where wmic' to https://github.com/thomasp85/shinyFiles/issues")
-        volumes <- Sys.getenv("HOMEDRIVE")                      
-        volNames <- ""
+        volumes_info <- system2("powershell", "$dvr=[System.IO.DriveInfo]::GetDrives();Write-Output $dvr.length $dvr.name $dvr.VolumeLabel;", stdout = TRUE)
+        num = as.integer(volumes_info[1])
+        if(num == 0) return(NULL)
+        mat <- matrix(volumes_info[-1], nrow = num, ncol = 2)
+        mat[, 1] <- gsub(":\\\\$", ":/", mat[, 1])
+        sel <- mat[, 2] == ""
+        mat[sel, 2] <- mat[sel, 1]
+        volumes <- mat[, 1]
+        volNames <- mat[, 2]
+        volNames <- paste0(volNames, " (", gsub(":/$", ":", volumes), ")")
       } else {
         volumes <- system(paste(wmic, "logicaldisk get Caption"), intern = TRUE, ignore.stderr=TRUE)
         volumes <- sub(" *\\r$", "", volumes)
@@ -87,11 +98,11 @@ getVolumes <- function(exclude) {
         volNames <- sub(" *\\r$", "", volNames)
         volNames <- volNames[keep]
         volNames <- paste0(volNames, ifelse(volNames == "", "", " "))
+        volNames <- paste0(volNames, "(", volumes, ")")
       }
-      volNames <- paste0(volNames, "(", volumes, ")")
       names(volumes) <- volNames
       volumes <- gsub(":$", ":/", volumes)
-  } else {
+    } else {
       stop("unsupported OS")
     }
     if (!is.null(exclude)) {
